# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: admin/v1/satellite.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from .types.v1 import satellite_pb2 as admin_dot_v1_dot_types_dot_v1_dot_satellite__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x18\x61\x64min/v1/satellite.proto\x12\x08\x61\x64min.v1\x1a!admin/v1/types/v1/satellite.proto\",\n\x16\x43reateSatelliteRequest\x12\x12\n\x04name\x18\x01 \x01(\tR\x04name\")\n\x17\x43reateSatelliteResponse\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\")\n\x17GetSatelliteByIdRequest\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\"V\n\x18GetSatelliteByIdResponse\x12:\n\tsatellite\x18\x01 \x01(\x0b\x32\x1c.admin.v1.types.v1.SatelliteR\tsatellite\"\x16\n\x14GetSatellitesRequest\"U\n\x15GetSatellitesResponse\x12<\n\nsatellites\x18\x01 \x03(\x0b\x32\x1c.admin.v1.types.v1.SatelliteR\nsatellites\"(\n\x16\x44\x65leteSatelliteRequest\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\"\x19\n\x17\x44\x65leteSatelliteResponse2\xef\x02\n\x10SatelliteService\x12V\n\x0f\x43reateSatellite\x12 .admin.v1.CreateSatelliteRequest\x1a!.admin.v1.CreateSatelliteResponse\x12Y\n\x10GetSatelliteById\x12!.admin.v1.GetSatelliteByIdRequest\x1a\".admin.v1.GetSatelliteByIdResponse\x12P\n\rGetSatellites\x12\x1e.admin.v1.GetSatellitesRequest\x1a\x1f.admin.v1.GetSatellitesResponse\x12V\n\x0f\x44\x65leteSatellite\x12 .admin.v1.DeleteSatelliteRequest\x1a!.admin.v1.DeleteSatelliteResponseB\xa9\x01\n\x0c\x63om.admin.v1B\x0eSatelliteProtoP\x01ZHgithub.com/formalco/control-plane/backend/admin-api/gen/admin/v1;adminv1\xa2\x02\x03\x41XX\xaa\x02\x08\x41\x64min.V1\xca\x02\x08\x41\x64min\\V1\xe2\x02\x14\x41\x64min\\V1\\GPBMetadata\xea\x02\tAdmin::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'admin.v1.satellite_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\014com.admin.v1B\016SatelliteProtoP\001ZHgithub.com/formalco/control-plane/backend/admin-api/gen/admin/v1;adminv1\242\002\003AXX\252\002\010Admin.V1\312\002\010Admin\\V1\342\002\024Admin\\V1\\GPBMetadata\352\002\tAdmin::V1'
  _globals['_CREATESATELLITEREQUEST']._serialized_start=73
  _globals['_CREATESATELLITEREQUEST']._serialized_end=117
  _globals['_CREATESATELLITERESPONSE']._serialized_start=119
  _globals['_CREATESATELLITERESPONSE']._serialized_end=160
  _globals['_GETSATELLITEBYIDREQUEST']._serialized_start=162
  _globals['_GETSATELLITEBYIDREQUEST']._serialized_end=203
  _globals['_GETSATELLITEBYIDRESPONSE']._serialized_start=205
  _globals['_GETSATELLITEBYIDRESPONSE']._serialized_end=291
  _globals['_GETSATELLITESREQUEST']._serialized_start=293
  _globals['_GETSATELLITESREQUEST']._serialized_end=315
  _globals['_GETSATELLITESRESPONSE']._serialized_start=317
  _globals['_GETSATELLITESRESPONSE']._serialized_end=402
  _globals['_DELETESATELLITEREQUEST']._serialized_start=404
  _globals['_DELETESATELLITEREQUEST']._serialized_end=444
  _globals['_DELETESATELLITERESPONSE']._serialized_start=446
  _globals['_DELETESATELLITERESPONSE']._serialized_end=471
  _globals['_SATELLITESERVICE']._serialized_start=474
  _globals['_SATELLITESERVICE']._serialized_end=841
# @@protoc_insertion_point(module_scope)



from .types.v1 import policy_pb2 as _policy_pb2
from .types.v1 import list_metadata_pb2 as _list_metadata_pb2
from ...validate.v1 import validate_pb2 as _validate_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class CreatePolicySuggestionRequest(_message.Message):
    __slots__ = ["name", "description"]
    NAME_FIELD_NUMBER: _ClassVar[int]
    DESCRIPTION_FIELD_NUMBER: _ClassVar[int]
    name: str
    description: str
    def __init__(self, name: _Optional[str] = ..., description: _Optional[str] = ...) -> None: ...

class CreatePolicySuggestionResponse(_message.Message):
    __slots__ = ["suggestion"]
    SUGGESTION_FIELD_NUMBER: _ClassVar[int]
    suggestion: str
    def __init__(self, suggestion: _Optional[str] = ...) -> None: ...

class DeletePolicyRequest(_message.Message):
    __slots__ = ["id"]
    ID_FIELD_NUMBER: _ClassVar[int]
    id: str
    def __init__(self, id: _Optional[str] = ...) -> None: ...

class DeletePolicyResponse(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...

class EvaluatePolicyValidityRequest(_message.Message):
    __slots__ = ["code"]
    CODE_FIELD_NUMBER: _ClassVar[int]
    code: str
    def __init__(self, code: _Optional[str] = ...) -> None: ...

class EvaluatePolicyValidityResponse(_message.Message):
    __slots__ = ["valid", "ast", "error"]
    VALID_FIELD_NUMBER: _ClassVar[int]
    AST_FIELD_NUMBER: _ClassVar[int]
    ERROR_FIELD_NUMBER: _ClassVar[int]
    valid: bool
    ast: str
    error: str
    def __init__(self, valid: bool = ..., ast: _Optional[str] = ..., error: _Optional[str] = ...) -> None: ...

class CreatePolicyRequest(_message.Message):
    __slots__ = ["name", "description", "code", "notification", "owners", "source_type", "active"]
    NAME_FIELD_NUMBER: _ClassVar[int]
    DESCRIPTION_FIELD_NUMBER: _ClassVar[int]
    CODE_FIELD_NUMBER: _ClassVar[int]
    NOTIFICATION_FIELD_NUMBER: _ClassVar[int]
    OWNERS_FIELD_NUMBER: _ClassVar[int]
    SOURCE_TYPE_FIELD_NUMBER: _ClassVar[int]
    ACTIVE_FIELD_NUMBER: _ClassVar[int]
    name: str
    description: str
    code: str
    notification: str
    owners: _containers.RepeatedScalarFieldContainer[str]
    source_type: str
    active: bool
    def __init__(self, name: _Optional[str] = ..., description: _Optional[str] = ..., code: _Optional[str] = ..., notification: _Optional[str] = ..., owners: _Optional[_Iterable[str]] = ..., source_type: _Optional[str] = ..., active: bool = ...) -> None: ...

class CreatePolicyResponse(_message.Message):
    __slots__ = ["policy"]
    POLICY_FIELD_NUMBER: _ClassVar[int]
    policy: _policy_pb2.Policy
    def __init__(self, policy: _Optional[_Union[_policy_pb2.Policy, _Mapping]] = ...) -> None: ...

class UpdatePolicyRequest(_message.Message):
    __slots__ = ["id", "source_type", "name", "description", "code", "notification", "owners", "active"]
    ID_FIELD_NUMBER: _ClassVar[int]
    SOURCE_TYPE_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    DESCRIPTION_FIELD_NUMBER: _ClassVar[int]
    CODE_FIELD_NUMBER: _ClassVar[int]
    NOTIFICATION_FIELD_NUMBER: _ClassVar[int]
    OWNERS_FIELD_NUMBER: _ClassVar[int]
    ACTIVE_FIELD_NUMBER: _ClassVar[int]
    id: str
    source_type: str
    name: str
    description: str
    code: str
    notification: str
    owners: _containers.RepeatedScalarFieldContainer[str]
    active: bool
    def __init__(self, id: _Optional[str] = ..., source_type: _Optional[str] = ..., name: _Optional[str] = ..., description: _Optional[str] = ..., code: _Optional[str] = ..., notification: _Optional[str] = ..., owners: _Optional[_Iterable[str]] = ..., active: bool = ...) -> None: ...

class UpdatePolicyResponse(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...

class GetPolicyRequest(_message.Message):
    __slots__ = ["policy_id"]
    POLICY_ID_FIELD_NUMBER: _ClassVar[int]
    policy_id: str
    def __init__(self, policy_id: _Optional[str] = ...) -> None: ...

class GetPolicyResponse(_message.Message):
    __slots__ = ["policy"]
    POLICY_FIELD_NUMBER: _ClassVar[int]
    policy: _policy_pb2.Policy
    def __init__(self, policy: _Optional[_Union[_policy_pb2.Policy, _Mapping]] = ...) -> None: ...

class GetPoliciesRequest(_message.Message):
    __slots__ = ["limit", "after", "before", "order"]
    LIMIT_FIELD_NUMBER: _ClassVar[int]
    AFTER_FIELD_NUMBER: _ClassVar[int]
    BEFORE_FIELD_NUMBER: _ClassVar[int]
    ORDER_FIELD_NUMBER: _ClassVar[int]
    limit: int
    after: str
    before: str
    order: str
    def __init__(self, limit: _Optional[int] = ..., after: _Optional[str] = ..., before: _Optional[str] = ..., order: _Optional[str] = ...) -> None: ...

class GetPoliciesResponse(_message.Message):
    __slots__ = ["policies", "list_metadata"]
    POLICIES_FIELD_NUMBER: _ClassVar[int]
    LIST_METADATA_FIELD_NUMBER: _ClassVar[int]
    policies: _containers.RepeatedCompositeFieldContainer[_policy_pb2.Policy]
    list_metadata: _list_metadata_pb2.ListMetadata
    def __init__(self, policies: _Optional[_Iterable[_Union[_policy_pb2.Policy, _Mapping]]] = ..., list_metadata: _Optional[_Union[_list_metadata_pb2.ListMetadata, _Mapping]] = ...) -> None: ...



from google.protobuf import timestamp_pb2 as _timestamp_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class CreateDatastoreRequest(_message.Message):
    __slots__ = ["name", "hostname", "port", "technology", "health_check_db_name", "db_discovery_job_wait_time", "db_discovery_native_role_id", "environment"]
    NAME_FIELD_NUMBER: _ClassVar[int]
    HOSTNAME_FIELD_NUMBER: _ClassVar[int]
    PORT_FIELD_NUMBER: _ClassVar[int]
    TECHNOLOGY_FIELD_NUMBER: _ClassVar[int]
    HEALTH_CHECK_DB_NAME_FIELD_NUMBER: _ClassVar[int]
    DB_DISCOVERY_JOB_WAIT_TIME_FIELD_NUMBER: _ClassVar[int]
    DB_DISCOVERY_NATIVE_ROLE_ID_FIELD_NUMBER: _ClassVar[int]
    ENVIRONMENT_FIELD_NUMBER: _ClassVar[int]
    name: str
    hostname: str
    port: int
    technology: str
    health_check_db_name: str
    db_discovery_job_wait_time: str
    db_discovery_native_role_id: str
    environment: str
    def __init__(self, name: _Optional[str] = ..., hostname: _Optional[str] = ..., port: _Optional[int] = ..., technology: _Optional[str] = ..., health_check_db_name: _Optional[str] = ..., db_discovery_job_wait_time: _Optional[str] = ..., db_discovery_native_role_id: _Optional[str] = ..., environment: _Optional[str] = ...) -> None: ...

class CreateDatastoreResponse(_message.Message):
    __slots__ = ["id"]
    ID_FIELD_NUMBER: _ClassVar[int]
    id: str
    def __init__(self, id: _Optional[str] = ...) -> None: ...

class GetDatastoreRequest(_message.Message):
    __slots__ = ["id"]
    ID_FIELD_NUMBER: _ClassVar[int]
    id: str
    def __init__(self, id: _Optional[str] = ...) -> None: ...

class GetDatastoreResponse(_message.Message):
    __slots__ = ["datastore"]
    DATASTORE_FIELD_NUMBER: _ClassVar[int]
    datastore: Datastore
    def __init__(self, datastore: _Optional[_Union[Datastore, _Mapping]] = ...) -> None: ...

class GetDatastoresRequest(_message.Message):
    __slots__ = ["limit", "cursor", "go_back"]
    LIMIT_FIELD_NUMBER: _ClassVar[int]
    CURSOR_FIELD_NUMBER: _ClassVar[int]
    GO_BACK_FIELD_NUMBER: _ClassVar[int]
    limit: int
    cursor: str
    go_back: bool
    def __init__(self, limit: _Optional[int] = ..., cursor: _Optional[str] = ..., go_back: bool = ...) -> None: ...

class GetDatastoresResponse(_message.Message):
    __slots__ = ["datastores", "last_evaluated_key", "has_more"]
    DATASTORES_FIELD_NUMBER: _ClassVar[int]
    LAST_EVALUATED_KEY_FIELD_NUMBER: _ClassVar[int]
    HAS_MORE_FIELD_NUMBER: _ClassVar[int]
    datastores: _containers.RepeatedCompositeFieldContainer[Datastore]
    last_evaluated_key: str
    has_more: bool
    def __init__(self, datastores: _Optional[_Iterable[_Union[Datastore, _Mapping]]] = ..., last_evaluated_key: _Optional[str] = ..., has_more: bool = ...) -> None: ...

class DeleteDatastoreRequest(_message.Message):
    __slots__ = ["id"]
    ID_FIELD_NUMBER: _ClassVar[int]
    id: str
    def __init__(self, id: _Optional[str] = ...) -> None: ...

class DeleteDatastoreResponse(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...

class UpdateDatastoreNameRequest(_message.Message):
    __slots__ = ["id", "name"]
    ID_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    id: str
    name: str
    def __init__(self, id: _Optional[str] = ..., name: _Optional[str] = ...) -> None: ...

class UpdateDatastoreNameResponse(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...

class UpdateDbDiscoveryConfigRequest(_message.Message):
    __slots__ = ["id", "db_discovery_job_wait_time", "db_discovery_native_role_id"]
    ID_FIELD_NUMBER: _ClassVar[int]
    DB_DISCOVERY_JOB_WAIT_TIME_FIELD_NUMBER: _ClassVar[int]
    DB_DISCOVERY_NATIVE_ROLE_ID_FIELD_NUMBER: _ClassVar[int]
    id: str
    db_discovery_job_wait_time: str
    db_discovery_native_role_id: str
    def __init__(self, id: _Optional[str] = ..., db_discovery_job_wait_time: _Optional[str] = ..., db_discovery_native_role_id: _Optional[str] = ...) -> None: ...

class UpdateDbDiscoveryConfigResponse(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...

class UpdateDataStoreHealthCheckDbNameRequest(_message.Message):
    __slots__ = ["id", "health_check_db_name"]
    ID_FIELD_NUMBER: _ClassVar[int]
    HEALTH_CHECK_DB_NAME_FIELD_NUMBER: _ClassVar[int]
    id: str
    health_check_db_name: str
    def __init__(self, id: _Optional[str] = ..., health_check_db_name: _Optional[str] = ...) -> None: ...

class UpdateDataStoreHealthCheckDbNameResponse(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...

class UpdateDataStoreDefaultAccessBehaviorRequest(_message.Message):
    __slots__ = ["id", "default_access_behavior"]
    ID_FIELD_NUMBER: _ClassVar[int]
    DEFAULT_ACCESS_BEHAVIOR_FIELD_NUMBER: _ClassVar[int]
    id: str
    default_access_behavior: str
    def __init__(self, id: _Optional[str] = ..., default_access_behavior: _Optional[str] = ...) -> None: ...

class UpdateDataStoreDefaultAccessBehaviorResponse(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...

class GetLinkedSidecarsRequest(_message.Message):
    __slots__ = ["id"]
    ID_FIELD_NUMBER: _ClassVar[int]
    id: str
    def __init__(self, id: _Optional[str] = ...) -> None: ...

class GetLinkedSidecarsResponse(_message.Message):
    __slots__ = ["sidecars"]
    SIDECARS_FIELD_NUMBER: _ClassVar[int]
    sidecars: _containers.RepeatedCompositeFieldContainer[LinkedSidecar]
    def __init__(self, sidecars: _Optional[_Iterable[_Union[LinkedSidecar, _Mapping]]] = ...) -> None: ...

class LinkedSidecar(_message.Message):
    __slots__ = ["id", "name", "hostname"]
    ID_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    HOSTNAME_FIELD_NUMBER: _ClassVar[int]
    id: str
    name: str
    hostname: str
    def __init__(self, id: _Optional[str] = ..., name: _Optional[str] = ..., hostname: _Optional[str] = ...) -> None: ...

class Datastore(_message.Message):
    __slots__ = ["id", "datastore_id", "name", "port", "hostname", "health_check_db_name", "technology", "created_at", "expire_at", "db_discovery_job_wait_time", "db_discovery_native_role_id", "default_access_behavior", "linked_logs", "environment"]
    ID_FIELD_NUMBER: _ClassVar[int]
    DATASTORE_ID_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    PORT_FIELD_NUMBER: _ClassVar[int]
    HOSTNAME_FIELD_NUMBER: _ClassVar[int]
    HEALTH_CHECK_DB_NAME_FIELD_NUMBER: _ClassVar[int]
    TECHNOLOGY_FIELD_NUMBER: _ClassVar[int]
    CREATED_AT_FIELD_NUMBER: _ClassVar[int]
    EXPIRE_AT_FIELD_NUMBER: _ClassVar[int]
    DB_DISCOVERY_JOB_WAIT_TIME_FIELD_NUMBER: _ClassVar[int]
    DB_DISCOVERY_NATIVE_ROLE_ID_FIELD_NUMBER: _ClassVar[int]
    DEFAULT_ACCESS_BEHAVIOR_FIELD_NUMBER: _ClassVar[int]
    LINKED_LOGS_FIELD_NUMBER: _ClassVar[int]
    ENVIRONMENT_FIELD_NUMBER: _ClassVar[int]
    id: str
    datastore_id: str
    name: str
    port: int
    hostname: str
    health_check_db_name: str
    technology: str
    created_at: _timestamp_pb2.Timestamp
    expire_at: str
    db_discovery_job_wait_time: str
    db_discovery_native_role_id: str
    default_access_behavior: str
    linked_logs: _containers.RepeatedCompositeFieldContainer[IntegrationLog]
    environment: str
    def __init__(self, id: _Optional[str] = ..., datastore_id: _Optional[str] = ..., name: _Optional[str] = ..., port: _Optional[int] = ..., hostname: _Optional[str] = ..., health_check_db_name: _Optional[str] = ..., technology: _Optional[str] = ..., created_at: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., expire_at: _Optional[str] = ..., db_discovery_job_wait_time: _Optional[str] = ..., db_discovery_native_role_id: _Optional[str] = ..., default_access_behavior: _Optional[str] = ..., linked_logs: _Optional[_Iterable[_Union[IntegrationLog, _Mapping]]] = ..., environment: _Optional[str] = ...) -> None: ...

class IntegrationLog(_message.Message):
    __slots__ = ["id", "name", "type", "created_at"]
    ID_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    TYPE_FIELD_NUMBER: _ClassVar[int]
    CREATED_AT_FIELD_NUMBER: _ClassVar[int]
    id: str
    name: str
    type: str
    created_at: int
    def __init__(self, id: _Optional[str] = ..., name: _Optional[str] = ..., type: _Optional[str] = ..., created_at: _Optional[int] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: admin/v1/identities.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from .types.v1 import external_id_pb2 as admin_dot_v1_dot_types_dot_v1_dot_external__id__pb2
from .types.v1 import group_pb2 as admin_dot_v1_dot_types_dot_v1_dot_group__pb2
from .types.v1 import user_pb2 as admin_dot_v1_dot_types_dot_v1_dot_user__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x19\x61\x64min/v1/identities.proto\x12\x08\x61\x64min.v1\x1a#admin/v1/types/v1/external_id.proto\x1a\x1d\x61\x64min/v1/types/v1/group.proto\x1a\x1c\x61\x64min/v1/types/v1/user.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"Y\n\x10GetGroupsRequest\x12\x14\n\x05limit\x18\x01 \x01(\x05R\x05limit\x12\x16\n\x06\x63ursor\x18\x02 \x01(\tR\x06\x63ursor\x12\x17\n\x07go_back\x18\x03 \x01(\x08R\x06goBack\"J\n\x12\x43reateGroupRequest\x12\x12\n\x04name\x18\x01 \x01(\tR\x04name\x12 \n\x0b\x64\x65scription\x18\x02 \x01(\tR\x0b\x64\x65scription\"%\n\x13GetGroupByIdRequest\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\"$\n\x12\x44\x65leteGroupRequest\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\"Z\n\x12UpdateGroupRequest\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\x12\x12\n\x04name\x18\x02 \x01(\tR\x04name\x12 \n\x0b\x64\x65scription\x18\x03 \x01(\tR\x0b\x64\x65scription\"D\n\x17LinkUsersToGroupRequest\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\x12\x19\n\x08user_ids\x18\x02 \x03(\tR\x07userIds\"H\n\x1bUnlinkUsersFromGroupRequest\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\x12\x19\n\x08user_ids\x18\x02 \x03(\tR\x07userIds\"E\n\x13\x43reateGroupResponse\x12.\n\x05group\x18\x01 \x01(\x0b\x32\x18.admin.v1.types.v1.GroupR\x05group\"F\n\x14GetGroupByIdResponse\x12.\n\x05group\x18\x01 \x01(\x0b\x32\x18.admin.v1.types.v1.GroupR\x05group\"E\n\x13\x44\x65leteGroupResponse\x12.\n\x05group\x18\x01 \x01(\x0b\x32\x18.admin.v1.types.v1.GroupR\x05group\"E\n\x13UpdateGroupResponse\x12.\n\x05group\x18\x01 \x01(\x0b\x32\x18.admin.v1.types.v1.GroupR\x05group\"\x8e\x01\n\x11GetGroupsResponse\x12\x30\n\x06groups\x18\x01 \x03(\x0b\x32\x18.admin.v1.types.v1.GroupR\x06groups\x12,\n\x12last_evaluated_key\x18\x02 \x01(\tR\x10lastEvaluatedKey\x12\x19\n\x08has_more\x18\x03 \x01(\x08R\x07hasMore\"P\n\x18LinkUsersToGroupResponse\x12\x19\n\x08user_ids\x18\x01 \x03(\tR\x07userIds\x12\x19\n\x08group_id\x18\x02 \x01(\tR\x07groupId\"T\n\x1cUnlinkUsersFromGroupResponse\x12\x19\n\x08user_ids\x18\x01 \x03(\tR\x07userIds\x12\x19\n\x08group_id\x18\x02 \x01(\tR\x07groupId\"M\n\x15UserLinkGroupResponse\x12\x19\n\x08user_ids\x18\x01 \x03(\tR\x07userIds\x12\x19\n\x08group_id\x18\x02 \x01(\tR\x07groupId\"X\n\x0fGetUsersRequest\x12\x14\n\x05limit\x18\x01 \x01(\tR\x05limit\x12\x16\n\x06\x63ursor\x18\x02 \x01(\tR\x06\x63ursor\x12\x17\n\x07go_back\x18\x03 \x01(\x08R\x06goBack\"\x8a\x01\n\x10GetUsersResponse\x12-\n\x05users\x18\x01 \x03(\x0b\x32\x17.admin.v1.types.v1.UserR\x05users\x12,\n\x12last_evaluated_key\x18\x02 \x01(\tR\x10lastEvaluatedKey\x12\x19\n\x08has_more\x18\x03 \x01(\x08R\x07hasMore\"\xb8\x02\n\x11\x43reateUserRequest\x12\x1d\n\nfirst_name\x18\x01 \x01(\tR\tfirstName\x12\x1b\n\tlast_name\x18\x02 \x01(\tR\x08lastName\x12\x12\n\x04type\x18\x03 \x01(\tR\x04type\x12\x19\n\x08\x61pp_type\x18\x04 \x01(\tR\x07\x61ppType\x12\x15\n\x06\x61pp_id\x18\x05 \x01(\tR\x05\x61ppId\x12\x12\n\x04name\x18\x06 \x01(\tR\x04name\x12\x14\n\x05\x65mail\x18\x07 \x01(\tR\x05\x65mail\x12\x14\n\x05\x61\x64min\x18\x08 \x01(\x08R\x05\x61\x64min\x12\x10\n\x03idp\x18\t \x01(\tR\x03idp\x12\x16\n\x06status\x18\n \x01(\tR\x06status\x12\x37\n\texpire_at\x18\x0b \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x08\x65xpireAt\"^\n\x12\x43reateUserResponse\x12+\n\x04user\x18\x01 \x01(\x0b\x32\x17.admin.v1.types.v1.UserR\x04user\x12\x1b\n\ttenant_id\x18\x02 \x01(\tR\x08tenantId\"$\n\x12GetUserByIdRequest\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\"B\n\x13GetUserByIdResponse\x12+\n\x04user\x18\x01 \x01(\x0b\x32\x17.admin.v1.types.v1.UserR\x04user\"#\n\x11\x44\x65leteUserRequest\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\"\x14\n\x12\x44\x65leteUserResponse\"\x89\x01\n\x11UpdateUserRequest\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\x12\x12\n\x04name\x18\x02 \x01(\tR\x04name\x12\x1d\n\nfirst_name\x18\x03 \x01(\tR\tfirstName\x12\x1b\n\tlast_name\x18\x04 \x01(\tR\x08lastName\x12\x14\n\x05\x65mail\x18\x05 \x01(\tR\x05\x65mail\"\x14\n\x12UpdateUserResponse\"0\n\x1eGetMachineUserAuthTokenRequest\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\"S\n\x1fGetMachineUserAuthTokenResponse\x12\x14\n\x05token\x18\x01 \x01(\tR\x05token\x12\x1a\n\x08username\x18\x02 \x01(\tR\x08username\"4\n\"RefreshMachineUserAuthTokenRequest\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\"W\n#RefreshMachineUserAuthTokenResponse\x12\x14\n\x05token\x18\x01 \x01(\tR\x05token\x12\x1a\n\x08username\x18\x02 \x01(\tR\x08username\"+\n\x19GetUserExternalIdsRequest\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\"^\n\x1aGetUserExternalIdsResponse\x12@\n\x0c\x65xternal_ids\x18\x01 \x03(\x0b\x32\x1d.admin.v1.types.v1.ExternalIdR\x0b\x65xternalIds\"\x8f\x01\n\x1aMapUserToExternalIdRequest\x12\x17\n\x07user_id\x18\x01 \x01(\tR\x06userId\x12\x1f\n\x0b\x65xternal_id\x18\x02 \x01(\tR\nexternalId\x12 \n\x0b\x64\x65scription\x18\x03 \x01(\tR\x0b\x64\x65scription\x12\x15\n\x06\x61pp_id\x18\x04 \x01(\tR\x05\x61ppId\"\x1d\n\x1bMapUserToExternalIdResponse\"?\n\x1e\x44\x65leteExternalIdMappingRequest\x12\x1d\n\nmapping_id\x18\x01 \x01(\tR\tmappingId\"!\n\x1f\x44\x65leteExternalIdMappingResponse2\x98\x07\n\x0bUserService\x12\x41\n\x08GetUsers\x12\x19.admin.v1.GetUsersRequest\x1a\x1a.admin.v1.GetUsersResponse\x12G\n\nCreateUser\x12\x1b.admin.v1.CreateUserRequest\x1a\x1c.admin.v1.CreateUserResponse\x12J\n\x0bGetUserById\x12\x1c.admin.v1.GetUserByIdRequest\x1a\x1d.admin.v1.GetUserByIdResponse\x12G\n\nDeleteUser\x12\x1b.admin.v1.DeleteUserRequest\x1a\x1c.admin.v1.DeleteUserResponse\x12G\n\nUpdateUser\x12\x1b.admin.v1.UpdateUserRequest\x1a\x1c.admin.v1.UpdateUserResponse\x12n\n\x17GetMachineUserAuthToken\x12(.admin.v1.GetMachineUserAuthTokenRequest\x1a).admin.v1.GetMachineUserAuthTokenResponse\x12z\n\x1bRefreshMachineUserAuthToken\x12,.admin.v1.RefreshMachineUserAuthTokenRequest\x1a-.admin.v1.RefreshMachineUserAuthTokenResponse\x12_\n\x12GetUserExternalIds\x12#.admin.v1.GetUserExternalIdsRequest\x1a$.admin.v1.GetUserExternalIdsResponse\x12\x62\n\x13MapUserToExternalId\x12$.admin.v1.MapUserToExternalIdRequest\x1a%.admin.v1.MapUserToExternalIdResponse\x12n\n\x17\x44\x65leteExternalIdMapping\x12(.admin.v1.DeleteExternalIdMappingRequest\x1a).admin.v1.DeleteExternalIdMappingResponse2\xc9\x04\n\x0cGroupService\x12J\n\x0b\x43reateGroup\x12\x1c.admin.v1.CreateGroupRequest\x1a\x1d.admin.v1.CreateGroupResponse\x12\x44\n\tGetGroups\x12\x1a.admin.v1.GetGroupsRequest\x1a\x1b.admin.v1.GetGroupsResponse\x12M\n\x0cGetGroupById\x12\x1d.admin.v1.GetGroupByIdRequest\x1a\x1e.admin.v1.GetGroupByIdResponse\x12J\n\x0bUpdateGroup\x12\x1c.admin.v1.UpdateGroupRequest\x1a\x1d.admin.v1.UpdateGroupResponse\x12Y\n\x10LinkUsersToGroup\x12!.admin.v1.LinkUsersToGroupRequest\x1a\".admin.v1.LinkUsersToGroupResponse\x12\x65\n\x14UnlinkUsersFromGroup\x12%.admin.v1.UnlinkUsersFromGroupRequest\x1a&.admin.v1.UnlinkUsersFromGroupResponse\x12J\n\x0b\x44\x65leteGroup\x12\x1c.admin.v1.DeleteGroupRequest\x1a\x1d.admin.v1.DeleteGroupResponseB\xaa\x01\n\x0c\x63om.admin.v1B\x0fIdentitiesProtoP\x01ZHgithub.com/formalco/control-plane/backend/admin-api/gen/admin/v1;adminv1\xa2\x02\x03\x41XX\xaa\x02\x08\x41\x64min.V1\xca\x02\x08\x41\x64min\\V1\xe2\x02\x14\x41\x64min\\V1\\GPBMetadata\xea\x02\tAdmin::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'admin.v1.identities_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\014com.admin.v1B\017IdentitiesProtoP\001ZHgithub.com/formalco/control-plane/backend/admin-api/gen/admin/v1;adminv1\242\002\003AXX\252\002\010Admin.V1\312\002\010Admin\\V1\342\002\024Admin\\V1\\GPBMetadata\352\002\tAdmin::V1'
  _globals['_GETGROUPSREQUEST']._serialized_start=170
  _globals['_GETGROUPSREQUEST']._serialized_end=259
  _globals['_CREATEGROUPREQUEST']._serialized_start=261
  _globals['_CREATEGROUPREQUEST']._serialized_end=335
  _globals['_GETGROUPBYIDREQUEST']._serialized_start=337
  _globals['_GETGROUPBYIDREQUEST']._serialized_end=374
  _globals['_DELETEGROUPREQUEST']._serialized_start=376
  _globals['_DELETEGROUPREQUEST']._serialized_end=412
  _globals['_UPDATEGROUPREQUEST']._serialized_start=414
  _globals['_UPDATEGROUPREQUEST']._serialized_end=504
  _globals['_LINKUSERSTOGROUPREQUEST']._serialized_start=506
  _globals['_LINKUSERSTOGROUPREQUEST']._serialized_end=574
  _globals['_UNLINKUSERSFROMGROUPREQUEST']._serialized_start=576
  _globals['_UNLINKUSERSFROMGROUPREQUEST']._serialized_end=648
  _globals['_CREATEGROUPRESPONSE']._serialized_start=650
  _globals['_CREATEGROUPRESPONSE']._serialized_end=719
  _globals['_GETGROUPBYIDRESPONSE']._serialized_start=721
  _globals['_GETGROUPBYIDRESPONSE']._serialized_end=791
  _globals['_DELETEGROUPRESPONSE']._serialized_start=793
  _globals['_DELETEGROUPRESPONSE']._serialized_end=862
  _globals['_UPDATEGROUPRESPONSE']._serialized_start=864
  _globals['_UPDATEGROUPRESPONSE']._serialized_end=933
  _globals['_GETGROUPSRESPONSE']._serialized_start=936
  _globals['_GETGROUPSRESPONSE']._serialized_end=1078
  _globals['_LINKUSERSTOGROUPRESPONSE']._serialized_start=1080
  _globals['_LINKUSERSTOGROUPRESPONSE']._serialized_end=1160
  _globals['_UNLINKUSERSFROMGROUPRESPONSE']._serialized_start=1162
  _globals['_UNLINKUSERSFROMGROUPRESPONSE']._serialized_end=1246
  _globals['_USERLINKGROUPRESPONSE']._serialized_start=1248
  _globals['_USERLINKGROUPRESPONSE']._serialized_end=1325
  _globals['_GETUSERSREQUEST']._serialized_start=1327
  _globals['_GETUSERSREQUEST']._serialized_end=1415
  _globals['_GETUSERSRESPONSE']._serialized_start=1418
  _globals['_GETUSERSRESPONSE']._serialized_end=1556
  _globals['_CREATEUSERREQUEST']._serialized_start=1559
  _globals['_CREATEUSERREQUEST']._serialized_end=1871
  _globals['_CREATEUSERRESPONSE']._serialized_start=1873
  _globals['_CREATEUSERRESPONSE']._serialized_end=1967
  _globals['_GETUSERBYIDREQUEST']._serialized_start=1969
  _globals['_GETUSERBYIDREQUEST']._serialized_end=2005
  _globals['_GETUSERBYIDRESPONSE']._serialized_start=2007
  _globals['_GETUSERBYIDRESPONSE']._serialized_end=2073
  _globals['_DELETEUSERREQUEST']._serialized_start=2075
  _globals['_DELETEUSERREQUEST']._serialized_end=2110
  _globals['_DELETEUSERRESPONSE']._serialized_start=2112
  _globals['_DELETEUSERRESPONSE']._serialized_end=2132
  _globals['_UPDATEUSERREQUEST']._serialized_start=2135
  _globals['_UPDATEUSERREQUEST']._serialized_end=2272
  _globals['_UPDATEUSERRESPONSE']._serialized_start=2274
  _globals['_UPDATEUSERRESPONSE']._serialized_end=2294
  _globals['_GETMACHINEUSERAUTHTOKENREQUEST']._serialized_start=2296
  _globals['_GETMACHINEUSERAUTHTOKENREQUEST']._serialized_end=2344
  _globals['_GETMACHINEUSERAUTHTOKENRESPONSE']._serialized_start=2346
  _globals['_GETMACHINEUSERAUTHTOKENRESPONSE']._serialized_end=2429
  _globals['_REFRESHMACHINEUSERAUTHTOKENREQUEST']._serialized_start=2431
  _globals['_REFRESHMACHINEUSERAUTHTOKENREQUEST']._serialized_end=2483
  _globals['_REFRESHMACHINEUSERAUTHTOKENRESPONSE']._serialized_start=2485
  _globals['_REFRESHMACHINEUSERAUTHTOKENRESPONSE']._serialized_end=2572
  _globals['_GETUSEREXTERNALIDSREQUEST']._serialized_start=2574
  _globals['_GETUSEREXTERNALIDSREQUEST']._serialized_end=2617
  _globals['_GETUSEREXTERNALIDSRESPONSE']._serialized_start=2619
  _globals['_GETUSEREXTERNALIDSRESPONSE']._serialized_end=2713
  _globals['_MAPUSERTOEXTERNALIDREQUEST']._serialized_start=2716
  _globals['_MAPUSERTOEXTERNALIDREQUEST']._serialized_end=2859
  _globals['_MAPUSERTOEXTERNALIDRESPONSE']._serialized_start=2861
  _globals['_MAPUSERTOEXTERNALIDRESPONSE']._serialized_end=2890
  _globals['_DELETEEXTERNALIDMAPPINGREQUEST']._serialized_start=2892
  _globals['_DELETEEXTERNALIDMAPPINGREQUEST']._serialized_end=2955
  _globals['_DELETEEXTERNALIDMAPPINGRESPONSE']._serialized_start=2957
  _globals['_DELETEEXTERNALIDMAPPINGRESPONSE']._serialized_end=2990
  _globals['_USERSERVICE']._serialized_start=2993
  _globals['_USERSERVICE']._serialized_end=3913
  _globals['_GROUPSERVICE']._serialized_start=3916
  _globals['_GROUPSERVICE']._serialized_end=4501
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: admin/v1/policies.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from .types.v1 import policy_pb2 as admin_dot_v1_dot_types_dot_v1_dot_policy__pb2
from .types.v1 import list_metadata_pb2 as admin_dot_v1_dot_types_dot_v1_dot_list__metadata__pb2
from ...validate.v1 import validate_pb2 as validate_dot_v1_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x17\x61\x64min/v1/policies.proto\x12\x08\x61\x64min.v1\x1a\x1e\x61\x64min/v1/types/v1/policy.proto\x1a%admin/v1/types/v1/list_metadata.proto\x1a\x1avalidate/v1/validate.proto\"g\n\x1d\x43reatePolicySuggestionRequest\x12\x1b\n\x04name\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01R\x04name\x12)\n\x0b\x64\x65scription\x18\x02 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01R\x0b\x64\x65scription\"@\n\x1e\x43reatePolicySuggestionResponse\x12\x1e\n\nsuggestion\x18\x01 \x01(\tR\nsuggestion\".\n\x13\x44\x65letePolicyRequest\x12\x17\n\x02id\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01R\x02id\"\x16\n\x14\x44\x65letePolicyResponse\"<\n\x1d\x45valuatePolicyValidityRequest\x12\x1b\n\x04\x63ode\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01R\x04\x63ode\"^\n\x1e\x45valuatePolicyValidityResponse\x12\x14\n\x05valid\x18\x01 \x01(\x08R\x05valid\x12\x10\n\x03\x61st\x18\x02 \x01(\tR\x03\x61st\x12\x14\n\x05\x65rror\x18\x03 \x01(\tR\x05\x65rror\"\xb6\x02\n\x13\x43reatePolicyRequest\x12\x1b\n\x04name\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01R\x04name\x12)\n\x0b\x64\x65scription\x18\x02 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01R\x0b\x64\x65scription\x12\x1b\n\x04\x63ode\x18\x03 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01R\x04\x63ode\x12\x46\n\x0cnotification\x18\x04 \x01(\tB\"\xfa\x42\x1fr\x1dR\x04noneR\x08\x63onsumerR\x06ownersR\x03\x61llR\x0cnotification\x12\x16\n\x06owners\x18\x05 \x03(\tR\x06owners\x12\x42\n\x0bsource_type\x18\x06 \x01(\tB!\xfa\x42\x1er\x1cR\x07\x63onsoleR\tterraformR\x06githubR\nsourceType\x12\x16\n\x06\x61\x63tive\x18\x07 \x01(\x08R\x06\x61\x63tive\"I\n\x14\x43reatePolicyResponse\x12\x31\n\x06policy\x18\x01 \x01(\x0b\x32\x19.admin.v1.types.v1.PolicyR\x06policy\"\xc6\x02\n\x13UpdatePolicyRequest\x12\x17\n\x02id\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01R\x02id\x12\x42\n\x0bsource_type\x18\x02 \x01(\tB!\xfa\x42\x1er\x1cR\x07\x63onsoleR\tterraformR\x06githubR\nsourceType\x12\x1b\n\x04name\x18\x03 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01R\x04name\x12)\n\x0b\x64\x65scription\x18\x04 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01R\x0b\x64\x65scription\x12\x12\n\x04\x63ode\x18\x05 \x01(\tR\x04\x63ode\x12\x46\n\x0cnotification\x18\x06 \x01(\tB\"\xfa\x42\x1fr\x1dR\x04noneR\x08\x63onsumerR\x06ownersR\x03\x61llR\x0cnotification\x12\x16\n\x06owners\x18\x07 \x03(\tR\x06owners\x12\x16\n\x06\x61\x63tive\x18\x08 \x01(\x08R\x06\x61\x63tive\"\x16\n\x14UpdatePolicyResponse\"/\n\x10GetPolicyRequest\x12\x1b\n\tpolicy_id\x18\x01 \x01(\tR\x08policyId\"F\n\x11GetPolicyResponse\x12\x31\n\x06policy\x18\x01 \x01(\x0b\x32\x19.admin.v1.types.v1.PolicyR\x06policy\"n\n\x12GetPoliciesRequest\x12\x14\n\x05limit\x18\x01 \x01(\x05R\x05limit\x12\x14\n\x05\x61\x66ter\x18\x02 \x01(\tR\x05\x61\x66ter\x12\x16\n\x06\x62\x65\x66ore\x18\x03 \x01(\tR\x06\x62\x65\x66ore\x12\x14\n\x05order\x18\x04 \x01(\tR\x05order\"\x92\x01\n\x13GetPoliciesResponse\x12\x35\n\x08policies\x18\x01 \x03(\x0b\x32\x19.admin.v1.types.v1.PolicyR\x08policies\x12\x44\n\rlist_metadata\x18\x02 \x01(\x0b\x32\x1f.admin.v1.types.v1.ListMetadataR\x0clistMetadata2\xf6\x04\n\rPolicyService\x12L\n\x0bGetPolicies\x12\x1c.admin.v1.GetPoliciesRequest\x1a\x1d.admin.v1.GetPoliciesResponse\"\x00\x12\x46\n\tGetPolicy\x12\x1a.admin.v1.GetPolicyRequest\x1a\x1b.admin.v1.GetPolicyResponse\"\x00\x12O\n\x0c\x43reatePolicy\x12\x1d.admin.v1.CreatePolicyRequest\x1a\x1e.admin.v1.CreatePolicyResponse\"\x00\x12O\n\x0cUpdatePolicy\x12\x1d.admin.v1.UpdatePolicyRequest\x1a\x1e.admin.v1.UpdatePolicyResponse\"\x00\x12O\n\x0c\x44\x65letePolicy\x12\x1d.admin.v1.DeletePolicyRequest\x1a\x1e.admin.v1.DeletePolicyResponse\"\x00\x12m\n\x16\x45valuatePolicyValidity\x12\'.admin.v1.EvaluatePolicyValidityRequest\x1a(.admin.v1.EvaluatePolicyValidityResponse\"\x00\x12m\n\x16\x43reatePolicySuggestion\x12\'.admin.v1.CreatePolicySuggestionRequest\x1a(.admin.v1.CreatePolicySuggestionResponse\"\x00\x42\xa8\x01\n\x0c\x63om.admin.v1B\rPoliciesProtoP\x01ZHgithub.com/formalco/control-plane/backend/admin-api/gen/admin/v1;adminv1\xa2\x02\x03\x41XX\xaa\x02\x08\x41\x64min.V1\xca\x02\x08\x41\x64min\\V1\xe2\x02\x14\x41\x64min\\V1\\GPBMetadata\xea\x02\tAdmin::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'admin.v1.policies_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\014com.admin.v1B\rPoliciesProtoP\001ZHgithub.com/formalco/control-plane/backend/admin-api/gen/admin/v1;adminv1\242\002\003AXX\252\002\010Admin.V1\312\002\010Admin\\V1\342\002\024Admin\\V1\\GPBMetadata\352\002\tAdmin::V1'
  _CREATEPOLICYSUGGESTIONREQUEST.fields_by_name['name']._options = None
  _CREATEPOLICYSUGGESTIONREQUEST.fields_by_name['name']._serialized_options = b'\372B\004r\002\020\001'
  _CREATEPOLICYSUGGESTIONREQUEST.fields_by_name['description']._options = None
  _CREATEPOLICYSUGGESTIONREQUEST.fields_by_name['description']._serialized_options = b'\372B\004r\002\020\001'
  _DELETEPOLICYREQUEST.fields_by_name['id']._options = None
  _DELETEPOLICYREQUEST.fields_by_name['id']._serialized_options = b'\372B\004r\002\020\001'
  _EVALUATEPOLICYVALIDITYREQUEST.fields_by_name['code']._options = None
  _EVALUATEPOLICYVALIDITYREQUEST.fields_by_name['code']._serialized_options = b'\372B\004r\002\020\001'
  _CREATEPOLICYREQUEST.fields_by_name['name']._options = None
  _CREATEPOLICYREQUEST.fields_by_name['name']._serialized_options = b'\372B\004r\002\020\001'
  _CREATEPOLICYREQUEST.fields_by_name['description']._options = None
  _CREATEPOLICYREQUEST.fields_by_name['description']._serialized_options = b'\372B\004r\002\020\001'
  _CREATEPOLICYREQUEST.fields_by_name['code']._options = None
  _CREATEPOLICYREQUEST.fields_by_name['code']._serialized_options = b'\372B\004r\002\020\001'
  _CREATEPOLICYREQUEST.fields_by_name['notification']._options = None
  _CREATEPOLICYREQUEST.fields_by_name['notification']._serialized_options = b'\372B\037r\035R\004noneR\010consumerR\006ownersR\003all'
  _CREATEPOLICYREQUEST.fields_by_name['source_type']._options = None
  _CREATEPOLICYREQUEST.fields_by_name['source_type']._serialized_options = b'\372B\036r\034R\007consoleR\tterraformR\006github'
  _UPDATEPOLICYREQUEST.fields_by_name['id']._options = None
  _UPDATEPOLICYREQUEST.fields_by_name['id']._serialized_options = b'\372B\004r\002\020\001'
  _UPDATEPOLICYREQUEST.fields_by_name['source_type']._options = None
  _UPDATEPOLICYREQUEST.fields_by_name['source_type']._serialized_options = b'\372B\036r\034R\007consoleR\tterraformR\006github'
  _UPDATEPOLICYREQUEST.fields_by_name['name']._options = None
  _UPDATEPOLICYREQUEST.fields_by_name['name']._serialized_options = b'\372B\004r\002\020\001'
  _UPDATEPOLICYREQUEST.fields_by_name['description']._options = None
  _UPDATEPOLICYREQUEST.fields_by_name['description']._serialized_options = b'\372B\004r\002\020\001'
  _UPDATEPOLICYREQUEST.fields_by_name['notification']._options = None
  _UPDATEPOLICYREQUEST.fields_by_name['notification']._serialized_options = b'\372B\037r\035R\004noneR\010consumerR\006ownersR\003all'
  _globals['_CREATEPOLICYSUGGESTIONREQUEST']._serialized_start=136
  _globals['_CREATEPOLICYSUGGESTIONREQUEST']._serialized_end=239
  _globals['_CREATEPOLICYSUGGESTIONRESPONSE']._serialized_start=241
  _globals['_CREATEPOLICYSUGGESTIONRESPONSE']._serialized_end=305
  _globals['_DELETEPOLICYREQUEST']._serialized_start=307
  _globals['_DELETEPOLICYREQUEST']._serialized_end=353
  _globals['_DELETEPOLICYRESPONSE']._serialized_start=355
  _globals['_DELETEPOLICYRESPONSE']._serialized_end=377
  _globals['_EVALUATEPOLICYVALIDITYREQUEST']._serialized_start=379
  _globals['_EVALUATEPOLICYVALIDITYREQUEST']._serialized_end=439
  _globals['_EVALUATEPOLICYVALIDITYRESPONSE']._serialized_start=441
  _globals['_EVALUATEPOLICYVALIDITYRESPONSE']._serialized_end=535
  _globals['_CREATEPOLICYREQUEST']._serialized_start=538
  _globals['_CREATEPOLICYREQUEST']._serialized_end=848
  _globals['_CREATEPOLICYRESPONSE']._serialized_start=850
  _globals['_CREATEPOLICYRESPONSE']._serialized_end=923
  _globals['_UPDATEPOLICYREQUEST']._serialized_start=926
  _globals['_UPDATEPOLICYREQUEST']._serialized_end=1252
  _globals['_UPDATEPOLICYRESPONSE']._serialized_start=1254
  _globals['_UPDATEPOLICYRESPONSE']._serialized_end=1276
  _globals['_GETPOLICYREQUEST']._serialized_start=1278
  _globals['_GETPOLICYREQUEST']._serialized_end=1325
  _globals['_GETPOLICYRESPONSE']._serialized_start=1327
  _globals['_GETPOLICYRESPONSE']._serialized_end=1397
  _globals['_GETPOLICIESREQUEST']._serialized_start=1399
  _globals['_GETPOLICIESREQUEST']._serialized_end=1509
  _globals['_GETPOLICIESRESPONSE']._serialized_start=1512
  _globals['_GETPOLICIESRESPONSE']._serialized_end=1658
  _globals['_POLICYSERVICE']._serialized_start=1661
  _globals['_POLICYSERVICE']._serialized_end=2291
# @@protoc_insertion_point(module_scope)
